==> redquicklib-1.289.0.tgz: package/lib/accountverificationservice.js <==
import createService from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';
import * as UIA from './actions/uiActions';
const endpoints = {
    Login: 'api/accountverification/login',
    ULogin: 'api/accountverification/ulogin',
    IsPendingIdentityConfirmation: 'api/accountverification/is/pending/identity/confirmation',
    IsVerified: 'api/accountverification/is/verified',
    StartVerificationProcess: 'api/accountverification/start/verification/process',
    VerifyAccount: 'api/accountverification/verify/account',
    IsProvider: 'api/accountverification/is/provider',
    IsLaborer: 'api/accountverification/is/laborer',
    IsHero: 'api/accountverification/is/hero',
    IsCustomer: 'api/accountverification/is/customer'
}
var formatjson = '?format=json';
var accountservice = createService();

export default {
    startVerificationProcess: async (email, phone) => {
        phone = phone ? phone.split(' ').join('') : null;
        email = email || null;
        UIA.log('email : ' + email);
        UIA.log('phone : ' + phone);
        var body = JSON.stringify({ email, phone });
        return accountservice.post(endpoints.StartVerificationProcess, body).then(res => {
            return res;
        });
        // return Globals.Delay(4).then(() => {
        //     UIA.log('start verification process');
        //     return true;
        //});
    },
    verifyAccount: async (verificationCode) => {
        return accountservice.post(endpoints.VerifyAccount, verificationCode).then(res => {

            UIA.log(res);

            return res;
        })
    },
    login: async (uniqueMachineSig) => {
        if (uniqueMachineSig) {
            return accountservice.post(endpoints.ULogin, uniqueMachineSig);
        }
        return accountservice.post(endpoints.Login);
    },
    isPendingIdentityConfirmation: async () => {
        return accountservice.get(endpoints.IsPendingIdentityConfirmation);
    },
    isVerified: async () => {
        return accountservice.get(endpoints.IsVerified)
    }
}

==> redquicklib-1.382.0.tgz: package/lib/accountverificationservice.js <==
import { createRedService } from './service';
import { parameters } from './endPoints';
import * as Globals from './globals';
import * as UIA from './actions/uiActions';
const endpoints = {
    Login: 'api/accountverification/login',
    ULogin: 'api/accountverification/ulogin',
    IsPendingIdentityConfirmation: 'api/accountverification/is/pending/identity/confirmation',
    IsVerified: 'api/accountverification/is/verified',
    StartVerificationProcess: 'api/accountverification/start/verification/process',
    VerifyAccount: 'api/accountverification/verify/account',
    IsProvider: 'api/accountverification/is/provider',
    IsLaborer: 'api/accountverification/is/laborer',
    IsHero: 'api/accountverification/is/hero',
    IsCustomer: 'api/accountverification/is/customer'
}
var formatjson = '?format=json';
var accountservice = createRedService();

export default {
    startVerificationProcess: async (email, phone) => {
        phone = phone ? phone.split(' ').join('') : null;
        email = email || null;
        UIA.log('email : ' + email);
        UIA.log('phone : ' + phone);
        var body = JSON.stringify({ email, phone });
        return accountservice.post(endpoints.StartVerificationProcess, body).then(res => {
            return res;
        });
        // return Globals.Delay(4).then(() => {
        //     UIA.log('start verification process');
        //     return true;
        //});
    },
    verifyAccount: async (verificationCode) => {
        return accountservice.post(endpoints.VerifyAccount, verificationCode).then(res => {

            UIA.log(res);

            return res;
        })
    },
    login: async (uniqueMachineSig) => {
        if (uniqueMachineSig) {
            return accountservice.post(endpoints.ULogin, uniqueMachineSig);
        }
        return accountservice.post(endpoints.Login);
    },
    isPendingIdentityConfirmation: async () => {
        return accountservice.get(endpoints.IsPendingIdentityConfirmation);
    },
    isVerified: async () => {
        return accountservice.get(endpoints.IsVerified)
    }
}
